#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   lua
version:                2.3.4
visibility:             public
id:                     lua-2.3.4-BL5zySoAldeKss7IbH83sP
key:                    lua-2.3.4-BL5zySoAldeKss7IbH83sP
license:                MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2025 Albert Krewinkel

maintainer:             Albert Krewinkel <tarleb@hslua.org>
author:                 Albert Krewinkel
homepage:               https://hslua.org/
synopsis:               Lua, an embeddable scripting language
description:
    This package provides bindings and types to bridge
    Haskell and <https://www.lua.org/ Lua>.

    The full Lua interpreter version 5.4.8 is included.
    Alternatively, a system-wide Lua installation can be
    linked instead.

category:               Foreign
abi:                    c6ad113a8ea6a111cf059d4fa64e3eaa
exposed:                True
exposed-modules:
    Lua Lua.Auxiliary Lua.Call Lua.Constants Lua.Debug Lua.Ersatz
    Lua.Ersatz.Auxiliary Lua.Ersatz.Functions Lua.Lib Lua.Primary
    Lua.Types Lua.Userdata Lua.Warn

import-dirs:            /usr/lib/ghc-9.6.6/site-local/lua-2.3.4
library-dirs:           /usr/lib/ghc-9.6.6/site-local/lua-2.3.4 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/lua-2.3.4 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-lua
hs-libraries:           HSlua-2.3.4-BL5zySoAldeKss7IbH83sP
extra-libraries:        lua5.4 m
extra-libraries-static: lua5.4 m
include-dirs:           /usr/include/lua5.4
includes:               lua.h luaconf.h lauxlib.h lualib.h
depends:                base-4.18.2.1
ld-options:             "-Wl,-E"
haddock-interfaces:     /usr/share/doc/haskell-lua/html/lua.haddock
haddock-html:           /usr/share/doc/haskell-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

